.. vim: ft=rst nospell tw=80

`Package Documentation <http://django-otp-agents.readthedocs.io/>`_

This uses `django-agent-trust`_ to add OTP-based machine authorization to
django-otp.

See `django-otp`_ for more information on the OTP framework.

This version is supported on Python 2.7 and 3.4+; and Django 1.8 and 1.10+.


.. _django-agent-trust: http://pypi.python.org/pypi/django-agent-trust
.. _django-otp: http://pypi.python.org/pypi/django-otp
